#!/bin/sh -xe

ln -s "$srcdir/dnspad.pcap" dnspad.pcap || true

../dnscap -g -r dnspad.pcap 2>dnspad.out
../dnscap -o use_layers=yes -g -r dnspad.pcap 2>>dnspad.out

diff dnspad.out "$srcdir/dnspad.gold"
